.. sacc documentation master file, created by
   sphinx-quickstart on Thu Apr 25 09:51:14 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to sacc's documentation!
=================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   intro
   api


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
